@@ -7,12 +7,14 @@ class AWSSQSHandler:
     """AWS ECS service handler."""
 
     service_name = 'sqs'
-    client = boto3.client(
-        service_name=service_name,
-        aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
-        aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY,
-        region_name=settings.AWS_DEFAULT_REGION,
-    )
+
+    def __init__(self):
+        self.client = boto3.client(
+            service_name=self.service_name,
+            aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
+            aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY,
+            region_name=settings.AWS_DEFAULT_REGION,
+        )
 
     def send_message(self, queue_url, data, **kwargs):
         return self.client.send_message(
